#!/bin/bash
#
# Startup script for the UNICORE UFTP server

#
# Installation directory
#
dir=`dirname $0`
if [ "${dir#/}" = "${dir}" ]
then
  if [ "$dir" != "." ]
  then
    dir="$(pwd)/$dir"
  else
    dir="$(pwd)"
  fi
fi

INST="${dir%/bin}"

#Alternatively specify the absolute path of the installation dir here
#INST=

#
# PID file
#
PID=$INST/uftpd.pid

#
# Console redirect file
#
STARTLOG=$INST/logs/startup.log


#
# source config file
#
. ${INST}/conf/uftpd.conf

#
# folder with jar files
#
LIB=${INST}/lib

#
# check whether a server is already running
#
if [ -e $PID ] 
 then 
  if [ -d /proc/$(cat $PID) ]
   then
     echo "A UFTPD instance may be already running with process id "$(cat $PID)
     echo "If this is not the case, delete the file $PID and re-run this script"
     exit 1
   fi
fi

#
# Java command 
#
JAVA=java

#
# Options to the Java VM
#

#
# helper function to set an option if it is not already set
#
# arg1: option name (without leading "-", e.g "Ducc.extensions")
# arg2: option value (e.g. =conf/extensions)
#
Options=( )
set_option(){
	if [[ "$UFTPD_OPTS" != *$1* ]]
	then
		N=${#Options[*]}
		Options[$N]="-$1$2"
	fi
}


#
# Memory for the VM
#
set_option "Xmx" "${UFTPD_MEM}m"


#
# log configuration
#
set_option "Dlog4j.configuration" "=file://${INST}/conf/logging.properties"


#
# SSL config file
#
set_option "Duftpd-ssl.conf" "=${SSL_CONF}"

#
# ACL file
#
set_option "Duftpd.acl" "=${ACL}"


#
# put all jars in lib folder on the classpath
#

CP=$(find "$LIB" -name "*.jar" -printf ":%p")
CP=."$CP"

PARAMS="-c $CMD_HOST -p $CMD_PORT -l $SERVER_HOST -L $SERVER_PORT"
PARAMS=$PARAMS" -m $MAX_CONNECTIONS -b $BUFFER_SIZE"
PARAMS=$PARAMS" -s $MAX_STREAMS"
if [ "$ADVERTISE_HOST" != "" ]; then
  PARAMS=$PARAMS" -a $ADVERTISE_HOST"
fi


CLASSPATH=$CP; export CLASSPATH

#
# path to native lib required for setuid
#
LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$LIB
export LD_LIBRARY_PATH

#
# go
#
nohup $JAVA "${Options[@]}" ${UFTPD_OPTS} eu.unicore.uftp.server.UFTPServer $PARAMS > $STARTLOG 2>&1 & echo $! > $PID

